@@ -54,12 +54,13 @@ def get_aza_fundamentals(stock_tic):
 
     try:
         driver.get(stock_url)
-        Print("Sucessfully got stock page")
+        print("Sucessfully got stock page")
     except Exception as e:
         print(stock_url)
         print(e)
 
     soup = BeautifulSoup(driver.page_source, 'html.parser')
+    print(soup)
 
     try:
         kort_namn = soup.find('aza-pair-list-key', string='Kortnamn')
